# 引用元
【Tkinter】[pythonで電卓を作ってみた](https://mzkw.hateblo.jp/entry/20191218/1576657973)より一部引用

# 使用したimport
## tkinterをtkとしてインポート
```python
import tkinter as tk
```
# classのApplicationで初期化と諸々の設定をする
```python
class Application(tk.Frame):
    
    def __init__(self, master=None):
        super().__init__(master)
``` 
# ボタンの位置をそれぞれ指定するためgeometryを使用
## Entryによって入力した数字の表示欄を作り、justify="right"で右寄せにしている
```python       
        self.master.geometry()
        self.master.title("電卓")
        self.entry = tk.Entry(self.master, justify="right")
```
# 工夫点1
## Menuでtkinter内にメニューバーを作りconfigで項目を設定
```python
        self.menu_bar = tk.Menu(self.master)
        self.master.config(menu=self.menu_bar)

        self.create_hyoji()
```
# 各種設定
## 入力 
```python
    def input(self, action):
        self.entry.insert(tk.END, action)
```
## 計算をすべてクリア
```python
    def clear_all(self):
        self.entry.delete(0, tk.END)
```
## 1文字消去
```python
    def clear_one(self):
        txt = self.entry.get()
        self.entry.delete(0, tk.END)
        self.entry.insert(0, txt[:-1])
```
## 計算結果を表示
```python
    def equals(self):
        self.value = eval(self.entry.get().replace("÷", "/").replace("x", "*").replace("%", "/100"))
        self.entry.delete(0, tk.END)
        self.entry.insert(0, self.value)
```
# 各種表示を設定
## 工夫点2
### 工夫点1で定義したmenu_barを組み込み、add_commandで「閉じる」のラベル、quitでアプリを終了できるようにする。また、add_cascadeでメニューがプルダウン形式で表示されるようにする。
```python
    def create_hyoji(self):
        file_menu = tk.Menu(self.menu_bar)
        file_menu.add_command(label="閉じる", command=self.master.quit)
        self.menu_bar.add_cascade(label="メニュー", menu=file_menu)
```
# 工夫点3 表示設定
## 入力表示欄の位置設定
```python
        self.entry.grid(row=0, column=0, columnspan=4, pady=3)
        self.entry.focus_set()
```
## ボタンの設定
### textにボタンの表示するラベルを、widthでボタンの幅を指定し、gridを使ってrowとcolumnでラベルの位置を指定した。
```python
        tk.Button(self.master, text="7", width=4,
                  command=lambda: self.input(7)).grid(row=2, column=0)
        tk.Button(self.master, text="8", width=4,
                  command=lambda: self.input(8)).grid(row=2, column=1)
        tk.Button(self.master, text="9", width=4,
                  command=lambda: self.input(9)).grid(row=2, column=2)

        tk.Button(self.master, text="4", width=4,
                  command=lambda: self.input(4)).grid(row=3, column=0)
        tk.Button(self.master, text="5", width=4,
                  command=lambda: self.input(5)).grid(row=3, column=1)
        tk.Button(self.master, text="6", width=4,
                  command=lambda: self.input(6)).grid(row=3, column=2)

        tk.Button(self.master, text="1", width=4,
                  command=lambda: self.input(1)).grid(row=4, column=0)
        tk.Button(self.master, text="2", width=4,
                  command=lambda: self.input(2)).grid(row=4, column=1)
        tk.Button(self.master, text="3", width=4,
                  command=lambda: self.input(3)).grid(row=4, column=2)

        tk.Button(self.master, text="0", width=10,
                  command=lambda: self.input(0)).grid(row=5, column=0, columnspan=2)
        tk.Button(self.master, text=".", width=4,
                  command=lambda: self.input(".")).grid(row=5, column=2)
        tk.Button(self.master, text="=", width=4,
                  command=self.equals).grid(row=5, column=3)

        tk.Button(self.master, text="x", width=4,
                  command=lambda: self.input("x")).grid(row=2, column=3)
        tk.Button(self.master, text="-", width=4,
                  command=lambda: self.input("-")).grid(row=3, column=3)
        tk.Button(self.master, text="+", width=4,
                  command=lambda: self.input("+")).grid(row=4, column=3)

        tk.Button(self.master, text="AC", width=4,
                  command=lambda: self.clear_all()).grid(row=1, column=0)
        tk.Button(self.master, text="C", width=4,
                  command=lambda: self.clear_one()).grid(row=1, column=1)
        tk.Button(self.master, text="%", width=4,
                  command=lambda: self.input("%")).grid(row=1, column=2)
        tk.Button(self.master, text="÷", width=4,
                  command=lambda: self.input("÷")).grid(row=1, column=3)
```
```python
root = tk.Tk()
app = Application(master=root)
app.mainloop()
```